psychopy_ext.exp.Task.show_text — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.show_text

`Task.` `show_text`(text='', wait=0, wait_stim=None, auto=0)

  Presents an instructions screen.

  Kwargs: | text (str, default: None) Text to show. wait (float, default: 0) How long to wait after the end of showing instructions, in seconds. wait_stim (stimulus or a list of stimuli, default: None) During this waiting, which stimuli should be shown. Usually, it would be a fixation spot. auto (float, default: 0) Duration of time-out of the instructions screen, in seconds.